"""Higher level module to handle data processing of BEA API results"""

import pandas as pd

from . import api


class BEA(api.BEAAPI):
    r"""The primary class in the BEApy package, handles sending requests
    and manipulating the results. Needs to be initiated with your BEA
    API key once, it is stored for all later requests.

    Parameters
    ----------
    api_key
        Your BEA API key
    """

    def __init__(self, api_key: str) -> None:
        super().__init__(api_key)

    def dataset_list(self) -> pd.DataFrame:
        r"""Get a list of all availible datasets (API method ``getDatasetList``)

        Returns
        -------
        pd.DataFrame
            A DataFrame with a description and name of availible datasets.
        """

        params = {
            'method': 'GETDATASETLIST'
        }

        results = self.send_request(params)

        return pd.DataFrame(results['Dataset'])
