import os

import pytest
import pandas as pd

from beapy import BEA
from beapy.api import BEAError


def test_wrong_id():
    """Test wrong ID, should catch a BEAError"""
    bea = BEA('WRONG-KEY')
    with pytest.raises(BEAError):
        bea.send_request({})

# From now on, the correct ID is used, so test can share a BEA object
@pytest.fixture(scope='session')
def api_key():
    return os.environ['BEA_API_KEY']


@pytest.fixture(scope='module')
def bea(api_key):
    bea = BEA(api_key)

    return bea


def test_wrong_param(bea):
    """Test wrong params, should catch a BEAError"""
    with pytest.raises(BEAError):
        bea.send_request({'WRONG PARAM': 0})


def test_wrong_method(bea):
    """Test wrong method name, should catch a BEAError"""
    with pytest.raises(BEAError):
        bea.send_request({'method': 'WRONG METHOD'})


@pytest.fixture(scope='module')
def dataset_list(bea):
    return bea.dataset_list()


class TestDatasetList(object):
    """This makes sure that the output of dataset_list() is what you
    would expect: a non-empty pd.DataFrame with 2 columns, one named
    'DatasetDescription', the other 'DatasetName'"""

    def test_type(self, dataset_list):
        assert isinstance(dataset_list, pd.DataFrame)

    def test_num_cols(self, dataset_list):
        assert dataset_list.shape[1] == 2

    def test_nonempty(self, dataset_list):
        assert dataset_list.shape[0] > 0

    def test_descr_column(self, dataset_list):
        assert 'DatasetDescription' in dataset_list.columns

    def test_name_column(self, dataset_list):
        assert 'DatasetName' in dataset_list.columns
